# AdviserResultResponseMetadataPython

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**api_version** | **int** |  |
**implementation_name** | **str** |  |
**major** | **int** |  |
**micro** | **int** |  |
**minor** | **int** |  |
**releaselevel** | **str** |  |
**serial** | **int** |  |

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

